@@ -1,12 +1,13 @@
 import dateparser
-import datetime
+from datetime import datetime, timezone
 
 import requests
-from typing import Union, Tuple, TypeVar, Callable, List, Type, Sequence
+from typing import Dict, Union, Tuple, TypeVar, Callable, List, Type, Sequence
 
 import math
 from shapely import wkt, errors
 
+
 number = TypeVar('number', int, float)
 
 def parse_string(value: str) -> str:
@@ -40,21 +41,27 @@ def parse_float(value: float) -> float:
     return value
 
 
-def parse_date(value: Union[str, datetime.datetime]) -> str:
+def parse_date(value: Union[str, datetime]) -> Union[datetime, str]:
     """
     Base date validator
     :param value: String or datetime object to be validated
     :return: String passed in, if it can successfully convert to Datetime.
     (Need to keep strings like "today" w/out converting them, but throw on "asdf")
     """
-    if isinstance(value, datetime.datetime):
-        return value
+    if isinstance(value, datetime):
+        return _to_utc(value)
+    
     date = dateparser.parse(str(value))
     if date is None:
         raise ValueError(f"Invalid date: '{value}'.")
-    return str(value)
-
+    
+    return _to_utc(date).strftime('%Y-%m-%dT%H:%M:%SZ')
 
+def _to_utc(date: datetime):
+    if date.tzinfo is None:
+        date = date.replace(tzinfo=timezone.utc)
+    return date
+    
 def parse_range(value: Tuple[number, number], h: Callable[[number], number]) -> Tuple[number, number]:
     """
     Base range validator. For our purposes, a range is a tuple with exactly two numeric elements (a, b), requiring a <= b.
@@ -79,7 +86,7 @@ def parse_range(value: Tuple[number, number], h: Callable[[number], number]) ->
 
 
 # Parse and validate a date range: "1991-10-01T00:00:00Z,1991-10-02T00:00:00Z"
-def parse_date_range(value: Tuple[Union[str, datetime.datetime], Union[str, datetime.datetime]]) -> Tuple[datetime.datetime, datetime.datetime]:
+def parse_date_range(value: Tuple[Union[str, datetime], Union[str, datetime]]) -> Tuple[datetime, datetime]:
     return parse_range(value, parse_date)
 
 
@@ -102,6 +109,22 @@ def parse_list(value: Sequence, h) -> List:
     except ValueError as exc:
         raise ValueError(f'Invalid {h.__name__} list: {exc}') from exc
 
+def parse_cmr_keywords_list(value: Sequence[Union[Dict, Sequence]]):
+    if not isinstance(value, Sequence) or (len(value) == 2 and isinstance(value[0], str)): # in case we're passed single key value pair as sequence
+        value = [value]
+    
+    for idx, item in enumerate(value):
+        if not isinstance(item, tuple) and not isinstance(item, Sequence):
+            raise ValueError(f"Expected item in cmr_keywords list index {idx} to be tuple pair, got value {item} of type {type(item)}")
+        if len(item) != 2:
+            raise ValueError(f"Expected item in cmr_keywords list index {idx} to be of length 2, got value {item} of length {len(item)}")
+        
+        search_key, search_value = item
+        if not isinstance(search_key, str) or not isinstance(search_value, str):
+            raise ValueError(f"Expected tuple pair of types: \"{type(str)}, {type(str)}\" in cmr_keywords at index {idx}, got value \"{str(item)}\" of types: \"{type(search_key)}, {type(search_value)}\"")
+
+    return value
+
 # Parse and validate an iterable of strings: "foo,bar,baz"
 def parse_string_list(value: Sequence[str]) -> List[str]:
     return parse_list(value, str)
