@@ -2,6 +2,208 @@ from typing import List
 
 
 dataset_collections = {
+    "NISAR": {
+        "NISAR_NEN_RRST_BETA_V1": [
+            "C1261815181-ASFDEV",
+            "C1261815288-ASF",
+            "C2850220296-ASF"
+        ],
+        "NISAR_NEN_RRST_PROVISIONAL_V1": [
+            "C1261832381-ASFDEV",
+            "C1261832657-ASF",
+            "C2853068083-ASF"
+        ],
+        "NISAR_NEN_RRST_V1": [
+            "C1256533420-ASFDEV",
+            "C1257349121-ASF",
+            "C2727902012-ASF"
+        ],
+        "NISAR_L0A_RRST_BETA_V1": [
+            "C1261813453-ASFDEV",
+            "C1261815147-ASF",
+            "C2850223384-ASF"
+        ],
+        "NISAR_L0A_RRST_PROVISIONAL_V1": [
+            "C1261832466-ASFDEV",
+            "C1261832658-ASF",
+            "C2853086824-ASF"
+        ],
+        "NISAR_L0A_RRST_V1": [
+            "C1256524081-ASFDEV",
+            "C1257349120-ASF",
+            "C2727901263-ASF"
+        ],
+        "NISAR_L0B_RRSD_BETA_V1": [
+            "C1261815274-ASFDEV",
+            "C1261815289-ASF",
+            "C2850224301-ASF"
+        ],
+        "NISAR_L0B_RRSD_PROVISIONAL_V1": [
+            "C1261832497-ASFDEV",
+            "C1261832659-ASF",
+            "C2853089814-ASF"
+        ],
+        "NISAR_L0B_RRSD_V1": [
+            "C1256358262-ASFDEV",
+            "C1257349115-ASF",
+            "C2727901639-ASF"
+        ],
+        "NISAR_L0B_CRSD_BETA_V1": [
+            "C1261815276-ASFDEV",
+            "C1261815301-ASF",
+            "C2850225137-ASF"
+        ],
+        "NISAR_L0B_CRSD_PROVISIONAL_V1": [
+            "C1261832632-ASFDEV",
+            "C1261832671-ASF",
+            "C2853091612-ASF"
+        ],
+        "NISAR_L0B_CRSD_V1": [
+            "C1256358463-ASFDEV",
+            "C1257349114-ASF",
+            "C2727901523-ASF"
+        ],
+        "NISAR_L1_RSLC_BETA_V1": [
+            "C1261813489-ASFDEV",
+            "C1261815148-ASF",
+            "C2850225585-ASF"
+        ],
+        "NISAR_L1_RSLC_PROVISIONAL_V1": [
+            "C1261832868-ASFDEV",
+            "C1261833052-ASF",
+            "C2853145197-ASF"
+        ],
+        "NISAR_L1_RSLC_V1": [
+            "C1256363301-ASFDEV",
+            "C1257349109-ASF",
+            "C2727900439-ASF"
+        ],
+        "NISAR_L1_RIFG_BETA_V1": [
+            "C1261819086-ASFDEV",
+            "C1261819120-ASF",
+            "C2850234202-ASF"
+        ],
+        "NISAR_L1_RIFG_PROVISIONAL_V1": [
+            "C1261832940-ASFDEV",
+            "C1261833063-ASF",
+            "C2853147928-ASF"
+        ],
+        "NISAR_L1_RIFG_V1": [
+            "C1256381769-ASFDEV",
+            "C1257349108-ASF",
+            "C2723110181-ASF"
+        ],
+        "NISAR_L1_RUNW_BETA_V1": [
+            "C1261819098-ASFDEV",
+            "C1261819121-ASF",
+            "C2850235455-ASF"
+        ],
+        "NISAR_L1_RUNW_PROVISIONAL_V1": [
+            "C1261832990-ASFDEV",
+            "C1261833064-ASF",
+            "C2853153429-ASF"
+        ],
+        "NISAR_L1_RUNW_V1": [
+            "C1256420738-ASFDEV",
+            "C1257349107-ASF",
+            "C2727900827-ASF"
+        ],
+        "NISAR_L1_ROFF_BETA_V1": [
+            "C1261819110-ASFDEV",
+            "C1261819145-ASF",
+            "C2850237619-ASF"
+        ],
+        "NISAR_L1_ROFF_PROVISIONAL_V1": [
+            "C1261832993-ASFDEV",
+            "C1261833076-ASF",
+            "C2853156054-ASF"
+        ],
+        "NISAR_L1_ROFF_V1": [
+            "C1256411631-ASFDEV",
+            "C1257349103-ASF",
+            "C2727900080-ASF"
+        ],
+        "NISAR_L2_GSLC_BETA_V1": [
+            "C1261819167-ASFDEV",
+            "C1261819258-ASF",
+            "C2850259510-ASF"
+        ],
+        "NISAR_L2_GSLC_PROVISIONAL_V1": [
+            "C1261833024-ASFDEV",
+            "C1261833127-ASF",
+            "C2854332392-ASF"
+        ],
+        "NISAR_L2_GSLC_V1": [
+            "C1256413628-ASFDEV",
+            "C1257349102-ASF",
+            "C2727896667-ASF"
+        ],
+        "NISAR_L2_GUNW_BETA_V1": [
+            "C1261819168-ASFDEV",
+            "C1261819270-ASF",
+            "C2850261892-ASF"
+        ],
+        "NISAR_L2_GUNW_PROVISIONAL_V1": [
+            "C1261833025-ASFDEV",
+            "C1261846741-ASF",
+            "C2854335566-ASF"
+        ],
+        "NISAR_L2_GUNW_V1": [
+            "C1256432264-ASFDEV",
+            "C1257349096-ASF",
+            "C2727897718-ASF"
+        ],
+        "NISAR_L2_GCOV_BETA_V1": [
+            "C1261819211-ASFDEV",
+            "C1261819275-ASF",
+            "C2850262927-ASF"
+        ],
+        "NISAR_L2_GCOV_PROVISIONAL_V1": [
+            "C1261833026-ASFDEV",
+            "C1261846880-ASF",
+            "C2854338529-ASF"
+        ],
+        "NISAR_L2_GCOV_V1": [
+            "C1256477304-ASFDEV",
+            "C1257349095-ASF",
+            "C2727896018-ASF"
+        ],
+        "NISAR_L2_GOFF_BETA_V1": [
+            "C1261819233-ASFDEV",
+            "C1261819281-ASF",
+            "C2850263910-ASF"
+        ],
+        "NISAR_L2_GOFF_PROVISIONAL_V1": [
+            "C1261833027-ASFDEV",
+            "C1261846994-ASF",
+            "C2854341702-ASF"
+        ],
+        "NISAR_L2_GOFF_V1": [
+            "C1256479237-ASFDEV",
+            "C1257349094-ASF",
+            "C2727896460-ASF"
+        ],
+        "NISAR_L3_SME2_BETA_V1": [
+            "C1261819245-ASFDEV",
+            "C1261819282-ASF",
+            "C2850265000-ASF"
+        ],
+        "NISAR_L3_SME2_PROVISIONAL_V1": [
+            "C1261833050-ASFDEV",
+            "C1261847095-ASF",
+            "C2854344945-ASF"
+        ],
+        "NISAR_L3_SME2_V1": [
+            "C1256568692-ASFDEV",
+            "C1257349093-ASF",
+            "C2727894546-ASF"
+        ],
+        "NISAR_CUSTOM_PROVISIONAL_V1": [
+            "C1262134528-ASFDEV",
+            "C1262135006-ASF",
+            "C2874824964-ASF"
+        ],
+    },
     "SENTINEL-1": {
         "SENTINEL-1A_SLC": ["C1214470488-ASF", "C1205428742-ASF", "C1234413245-ASFDEV"],
         "SENTINEL-1B_SLC": ["C1327985661-ASF", "C1216244348-ASF", "C1234413263-ASFDEV"],
@@ -230,7 +432,8 @@ dataset_collections = {
         "SENTINEL-1_INTERFEROGRAMS_UNWRAPPED_PHASE": [
             "C1595765183-ASF",
             "C1225776659-ASF",
-        ]
+        ],
+        "ARIA_S1_GUNW": ["C2859376221-ASF", "C1261881077-ASF"]
     },
     "SMAP": {
         "SPL1A_RO_METADATA_003": ["C1243122884-ASF", "C1233103964-ASF"],
@@ -337,6 +540,8 @@ collections_per_platform = {
         "C1214470533-ASF",
         "C1214470576-ASF",
         "C1595422627-ASF",
+        "C2859376221-ASF",
+        "C1261881077-ASF",
         "C1214470496-ASF",
         "C1214470532-ASF",
         "C1214472977-ASF",
@@ -735,6 +940,131 @@ collections_per_platform = {
         "C1210599503-ASF",
         "C1210599673-ASF",
     ],
+    "NISAR": [  
+        # UAT ASFDEV
+        "C1261815181-ASFDEV",
+        "C1261832381-ASFDEV",
+        "C1256533420-ASFDEV",
+        "C1261813453-ASFDEV",
+        "C1261832466-ASFDEV",
+        "C1256524081-ASFDEV",
+        "C1261815274-ASFDEV",
+        "C1261832497-ASFDEV",
+        "C1256358262-ASFDEV",
+        "C1261815276-ASFDEV",
+        "C1261832632-ASFDEV",
+        "C1256358463-ASFDEV",
+        "C1261813489-ASFDEV",
+        "C1261832868-ASFDEV",
+        "C1256363301-ASFDEV",
+        "C1261819086-ASFDEV",
+        "C1261832940-ASFDEV",
+        "C1256381769-ASFDEV",
+        "C1261819098-ASFDEV",
+        "C1261832990-ASFDEV",
+        "C1256420738-ASFDEV",
+        "C1261819110-ASFDEV",
+        "C1261832993-ASFDEV",
+        "C1256411631-ASFDEV",
+        "C1261819167-ASFDEV",
+        "C1261833024-ASFDEV",
+        "C1256413628-ASFDEV",
+        "C1261819168-ASFDEV",
+        "C1261833025-ASFDEV",
+        "C1256432264-ASFDEV",
+        "C1261819211-ASFDEV",
+        "C1261833026-ASFDEV",
+        "C1256477304-ASFDEV",
+        "C1261819233-ASFDEV",
+        "C1261833027-ASFDEV",
+        "C1256479237-ASFDEV",
+        "C1261819245-ASFDEV",
+        "C1261833050-ASFDEV",
+        "C1256568692-ASFDEV",
+        "C1262134528-ASFDEV",
+        # UAT
+        "C1261815288-ASF",
+        "C1261832657-ASF",
+        "C1257349121-ASF",
+        "C1261815147-ASF",
+        "C1261832658-ASF",
+        "C1257349120-ASF",
+        "C1261815289-ASF",
+        "C1261832659-ASF",
+        "C1257349115-ASF",
+        "C1261815301-ASF",
+        "C1261832671-ASF",
+        "C1257349114-ASF",
+        "C1261815148-ASF",
+        "C1261833052-ASF",
+        "C1257349109-ASF",
+        "C1261819120-ASF",
+        "C1261833063-ASF",
+        "C1257349108-ASF",
+        "C1261819121-ASF",
+        "C1261833064-ASF",
+        "C1257349107-ASF",
+        "C1261819145-ASF",
+        "C1261833076-ASF",
+        "C1257349103-ASF",
+        "C1261819258-ASF",
+        "C1261833127-ASF",
+        "C1257349102-ASF",
+        "C1261819270-ASF",
+        "C1261846741-ASF",
+        "C1257349096-ASF",
+        "C1261819275-ASF",
+        "C1261846880-ASF",
+        "C1257349095-ASF",
+        "C1261819281-ASF",
+        "C1261846994-ASF",
+        "C1257349094-ASF",
+        "C1261819282-ASF",
+        "C1261847095-ASF",
+        "C1257349093-ASF",
+        "C1262135006-ASF",
+        # PROD
+        "C2850220296-ASF",
+        "C2853068083-ASF",
+        "C2727902012-ASF",
+        "C2850223384-ASF",
+        "C2853086824-ASF",
+        "C2727901263-ASF",
+        "C2850224301-ASF",
+        "C2853089814-ASF",
+        "C2727901639-ASF",
+        "C2850225137-ASF",
+        "C2853091612-ASF",
+        "C2727901523-ASF",
+        "C2850225585-ASF",
+        "C2853145197-ASF",
+        "C2727900439-ASF",
+        "C2850234202-ASF",
+        "C2853147928-ASF",
+        "C2723110181-ASF",
+        "C2850235455-ASF",
+        "C2853153429-ASF",
+        "C2727900827-ASF",
+        "C2850237619-ASF",
+        "C2853156054-ASF",
+        "C2727900080-ASF",
+        "C2850259510-ASF",
+        "C2854332392-ASF",
+        "C2727896667-ASF",
+        "C2850261892-ASF",
+        "C2854335566-ASF",
+        "C2727897718-ASF",
+        "C2850262927-ASF",
+        "C2854338529-ASF",
+        "C2727896018-ASF",
+        "C2850263910-ASF",
+        "C2854341702-ASF",
+        "C2727896460-ASF",
+        "C2850265000-ASF",
+        "C2854344945-ASF",
+        "C2727894546-ASF",
+        "C2874824964-ASF"
+    ],
 }
 
 
@@ -838,6 +1168,7 @@ collections_by_processing_level = {
         "C1234413238-ASFDEV",
         "C1327985647-ASF",
         "C1216244592-ASF",
+        "C1234413256-ASFDEV",
     ],
     "GRD_MD": [
         "C1214471521-ASF",
@@ -896,14 +1227,8 @@ collections_by_processing_level = {
         "C1595765183-ASF",
         "C1225776659-ASF",
     ],
-    "CSLC-STATIC": [
-        "C1259982010-ASF", 
-        "C2795135668-ASF"
-    ],
-    "RTC-STATIC": [
-        "C1259981910-ASF",
-        "C2795135174-ASF"
-    ],
+    "CSLC-STATIC": ["C1259982010-ASF", "C2795135668-ASF"],
+    "RTC-STATIC": ["C1259981910-ASF", "C2795135174-ASF"],
     "GRD": [
         "C1661710583-ASF",
         "C1661710586-ASF",
@@ -1077,13 +1402,14 @@ collections_by_processing_level = {
 
 #################### Helper Methods ####################
 
+
 def get_concept_id_alias(param_list: List[str], collections_dict: dict) -> List[str]:
     """
     param: param_list (List[str]): list of search values to alias
     param: collections_dict (dict): The search value to concept-id dictionary to read from
 
     returns List[str]: Returns a list of concept-ids that correspond to the given list of search values
-    If any of the search values are not keys in the collections_dict, this will instead returns an empty list. 
+    If any of the search values are not keys in the collections_dict, this will instead returns an empty list.
     """
     concept_id_aliases = []
     for param in param_list:
@@ -1091,9 +1417,10 @@ def get_concept_id_alias(param_list: List[str], collections_dict: dict) -> List[
             concept_id_aliases.extend(alias)
         else:
             return []
-    
+
     return concept_id_aliases
 
+
 def get_dataset_concept_ids(datasets: List[str]) -> List[str]:
     """
     Returns concept-ids for provided dataset(s)
@@ -1108,6 +1435,8 @@ def get_dataset_concept_ids(datasets: List[str]) -> List[str]:
             for concept_ids in collections_by_short_name.values():
                 output.extend(concept_ids)
         else:
-            raise ValueError(f'Could not find dataset named "{dataset}" provided for dataset keyword.')
-    
-    return output
\ No newline at end of file
+            raise ValueError(
+                f'Could not find dataset named "{dataset}" provided for dataset keyword.'
+            )
+
+    return output
