@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional
 from asf_search.ASFSearchOptions import ASFSearchOptions
 from asf_search.CMR.datasets import get_concept_id_alias
@@ -8,8 +8,8 @@ from shapely import wkt
 from shapely.geometry import Polygon
 from shapely.geometry.base import BaseGeometry
 from .field_map import field_map
-from .datasets import dataset_collections, collections_per_platform
-
+from .datasets import collections_per_platform
+import ciso8601
 import logging
 
 
@@ -51,6 +51,10 @@ def translate_opts(opts: ASFSearchOptions) -> List:
     
     # convert the above parameters to a list of key/value tuples
     cmr_opts = []
+
+    # user provided umm fields
+    custom_cmr_keywords = dict_opts.pop('cmr_keywords', [])
+
     for (key, val) in dict_opts.items():
         # If it's "session" or something else CMR doesn't accept, don't send it:
         if key not in field_map:
@@ -74,6 +78,8 @@ def translate_opts(opts: ASFSearchOptions) -> List:
     if should_use_asf_frame(cmr_opts):
             cmr_opts = use_asf_frame(cmr_opts)
 
+    cmr_opts.extend(custom_cmr_keywords)
+
     additional_keys = [
         ('page_size', CMR_PAGE_SIZE),
         ('options[temporal][and]', 'true'), 
@@ -147,6 +153,24 @@ def try_parse_float(value: str) -> Optional[float]:
     
     return float(value)
 
+def try_parse_date(value: str) -> Optional[str]:
+    if value is None:
+        return None
+
+    try:
+        date = ciso8601.parse_datetime(value)
+    except ValueError:
+        return None
+    
+    if date is None:
+        return value
+
+    if date.tzinfo is None:
+        date = date.replace(tzinfo=timezone.utc)
+        # Turn all inputs into a consistant format:
+
+    return date.strftime('%Y-%m-%dT%H:%M:%SZ')
+
 def fix_date(fixed_params: Dict[str, Any]):
     if 'start' in fixed_params or 'end' in fixed_params or 'season' in fixed_params:
         fixed_params["start"] = fixed_params["start"] if "start" in fixed_params else "1978-01-01T00:00:00Z"
